pub struct Hub<T: DataDeliveryPolicy + Clone> { /* private fields */ }Expand description
Sync data communcation hub to implement in-process pub/sub model for thread workers
Implementations
Sourceimpl<T: DataDeliveryPolicy + Clone> Hub<T>
impl<T: DataDeliveryPolicy + Clone> Hub<T>
Sourcepub fn set_default_channel_capacity(self, capacity: usize) -> Self
pub fn set_default_channel_capacity(self, capacity: usize) -> Self
Sets the default client channel capacity (the default is 1024), can be used as a build pattern
Sourcepub fn send_checked<F>(&self, message: T, error_handler: F) -> Result<()>
pub fn send_checked<F>(&self, message: T, error_handler: F) -> Result<()>
Sends a message to subscribed clients, calls an error handlers function in case of errors with some subsciber
If the error function returns false, the whole operation is aborted
Panics
Should not panic
Sourcepub fn sender(&self) -> Client<T> ⓘ
pub fn sender(&self) -> Client<T> ⓘ
Registers a sender-only client with no subscriptions
If attempting to receive a message from such client, Error::ChannelClosed is returned
Sourcepub fn register<F>(&self, name: &str, condition: F) -> Result<Client<T>>
pub fn register<F>(&self, name: &str, condition: F) -> Result<Client<T>>
Registers a regular client. The condition function is used to check which kinds of messages should be delivered (returns true for subscribed)
Sourcepub fn register_with_options(
&self,
client_options: ClientOptions<T>,
) -> Result<Client<T>>
pub fn register_with_options( &self, client_options: ClientOptions<T>, ) -> Result<Client<T>>
Registers a regular client with custom options